@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-%CFG = (
+my %CFG = (
    test_key_1 => '11',  
    test_key_2 => '22',  
 );
